Alignment

Enum Alignment 

pub enum Alignment {
    Left,
    Center,
    Right,
    LeftEndTab,
    LeftFwf,
}
Alignment represents how a TabWriter should align text within its cell.

Variants



Left

Text should be aligned with the left edge of the cell



Center

Text should be centered within the cell



Right

Text should be aligned with the right edge of the cell



LeftEndTab

Like Left, but the last whitespace is a tab This produces a valid TSV file



LeftFwf

Like Left, but adds a comment line at the top that comma-delimited enumerates the starting position of each column (Fixed Width Format). Positions are 1-indexed.